@@ -20,7 +20,7 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-
+import json
 from datetime import datetime, timezone
 
 from thetaetl.service.graph_operations import GraphOperations, OutOfBoundsError, Point
@@ -74,20 +74,20 @@ class BlockTimestampGraph(object):
 
     def get_first_point(self):
         # Ignore the genesis block as its timestamp is 0
-        # response = self._theta_provider.make_request(
-        #     json.dumps(generate_get_blocks_by_range_json_rpc(1, 1, False))
-        #     )
-        response = self._theta_provider.make_request(generate_get_blocks_by_range_json_rpc(1, 1, False))
-        results = rpc_response_to_result(response)
-        blocks = [self.block_mapper.json_dict_to_block(result) for result in results]
-
-        return block_to_point(blocks[0]) #TODO: make text
+        return get_point(1)
 
     def get_last_point(self):
-        return block_to_point(self._theta_provider.eth.getBlock('latest'))
+#        return block_to_point(self._theta_provider.eth.getBlock('latest'))  
+        return get_point(6779286) #TODO: query status to get latest
 
     def get_point(self, x):
-        return block_to_point(self._theta_provider.eth.getBlock(x))
+#        return block_to_point(self._theta_provider.eth.getBlock(x))
+        response = self._theta_provider.make_request(
+            json.dumps(generate_get_blocks_by_range_json_rpc(x, x, False))
+            )
+        results = rpc_response_to_result(response)
+        blocks = [self.block_mapper.json_dict_to_block(result) for result in results]
+        return block_to_point(blocks[0])
 
 
 def block_to_point(block):
